@@ -29,7 +29,7 @@ class Validator:
       validate(instance=instance_yml, schema=schema_yml)
       return instance_yml
     except ValidationError as err:
-      msg = {"type": "InvalidInstanceError",
+      msg = {"type": "InvalidSchemaInstanceError",
              "message": f"Instance is invalid: {err.message}"}
       logging.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
@@ -49,31 +49,37 @@ class Validator:
     Raises:
       ``laboro.error.LaboroError``: When the given ``args`` does not validate against the specification.
     """
-    if "args" not in method:
-      if len(args) > 0:
-        msg = {"type": "TooManyArgsError",
-               "message": f"Method does not accept args: {method['name']}"}
-        logging.critical(f"[{msg['type']}] {msg['message']}")
-        raise LaboroError(f"[{msg['type']}] {msg['message']}")
-      return
-    if not isinstance(args, dict):
-      msg = f"[MethodArgError]: Expected dict, received {type(args)}"
-      logging.critical(msg)
-      raise LaboroError(msg)
-    if not self._validate_required(args, method):
-      msg = "[MissingRequiredArgError] Missing required argument."
-      logging.critical(msg)
-      raise LaboroError(msg)
-    for arg, value in args.items():
-      if arg in [arg["name"] for arg in method["args"]]:
-        self._validate_type(arg, value, method)
-        self._validate_implied(arg, args, method)
-        self._validate_excluded(arg, args, method)
-      else:
-        msg = {"type": "UnknownMethodArgError",
-               "message": f"Unknown argument: {arg}"}
-        logging.critical(f"[{msg['type']}] {msg['message']}")
-        raise LaboroError(f"[{msg['type']}] {msg['message']}")
+    try:
+      if method.get("args") is None:
+        if len(args) > 0:
+          msg = {"type": "TooManyArgsError",
+                 "message": f"Method does not accept args: {method['name']}"}
+          logging.critical(f"[{msg['type']}] {msg['message']}")
+          raise LaboroError(f"[{msg['type']}] {msg['message']}")
+        return
+      if not isinstance(args, dict):
+        msg = f"[MethodArgError]: Expected dict, received {type(args)}"
+        logging.critical(msg)
+        raise LaboroError(msg)
+      if not self._validate_required(args, method):
+        msg = "[MissingRequiredArgError] Missing required argument."
+        logging.critical(msg)
+        raise LaboroError(msg)
+      for arg, value in args.items():
+        if arg in [arg["name"] for arg in method["args"]]:
+          self._validate_type(arg, value, method)
+          self._validate_implied(arg, args, method)
+          self._validate_excluded(arg, args, method)
+        else:
+          msg = {"type": "UnknownMethodArgError",
+                 "message": f"Unknown argument: {arg}"}
+          logging.critical(f"[{msg['type']}] {msg['message']}")
+          raise LaboroError(f"[{msg['type']}] {msg['message']}")
+    except AttributeError as err:
+      msg = {"type": "InvalidMethodSpecTypeError",
+             "message": f"Specification must be dict. Received: {type(method)}"}
+      logging.critical(f"[{msg['type']}] {msg['message']}")
+      raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
   def validate_obj_args(self, specification, args):
     """Validate the instantiation arguments against the object specification.
@@ -91,7 +97,7 @@ class Validator:
       logging.critical(msg)
       raise LaboroError(msg)
     obj = self._load_file(specification)
-    if "args" not in obj:
+    if obj.get("args") is None:
       if len(args) > 0:
         msg = {"type": "TooManyArgsError",
                "message": f"Object constructor does not accept args: {obj['class']}"}
